@@ -17,10 +17,9 @@ ggplot_build <- function(plot) {
   
   #if we have ternary coordinate system but not ternary plot class, make it ternary.
   if(inherits(plot$coordinates,"ternary")){
-    if(!inherits(plot,"ggtern")){
+    if(!inherits(plot,"ggtern") & inherits(plot,"ggplot"))
       class(plot) <- c("ggtern",class(plot))
-    }
-    plot <- plot + .theme_nocart()
+    plot <- plot + .theme_nocart() #destroy any cartesian theme elements
   }
   
   # Initialise panels, add extra data for margins & missing facetting
@@ -34,42 +33,49 @@ ggplot_build <- function(plot) {
     ##Strip Unapproved Ternary Layers
     plot$layers <- strip_unapproved(plot$layers)
     
-    ##Check that there are layers.
-    if(length(plot$layers) == 0){stop("No layers in plot",call.=F)}  
-    
-    #The ternary axis names.
-    scales.tern <- c("T","L","R","x","y")
-    
-    #names(which(plot$coordinates=="y"))
-    ix <- function(x){names(plot$coordinates)[which(plot$coordinates == x)]}
-    
-    ##Add the missing scales
-    ggint$scales_add_missing(plot,scales.tern,environment())
-    for(i in 1:3)
-      assign(paste0("scale_",scales.tern[i]),plot$scales$get_scales(scales.tern[i]))
+    ##Check that there are layers remaining after potentially stripping all layers
+    if(length(plot$layers) == 0){stop("No layers in ternary plot",call.=F)}  
     
     ##Add the ternary fixed coordinates if it doesn't exist
     if(!inherits(plot$coordinates,"ternary")){plot <- plot + coord_tern()}
     
-    ##Update the scales limits from the coordinate
-    for(X in scales.tern)
-      plot$coordinates$limits[[X]] <- .is.numericor(.select.lim(plot$scales$get_scales(X)$limits,
-                                                                plot$coordinates$limits[[X]]),c(0,1))
+    #The ternary and cartesian axis names.
+    scales.tern <- plot$coordinates$required_axes #c("T","L","R")
+    scales.aes  <- plot$coordinates$required_aes  #c("x","y","z")
+    scales.cart <- c("x","y")
     
-    #STORE COORDINATES FOR USE BY OTHER METHODS.
-    set_last_coord(plot$coordinates)
+    ##Add the missing scales
+    ggint$scales_add_missing(plot,c(scales.tern,scales.cart),environment())
     
-    #THESE ARE A BIT OF A HACK. NORMALLY THIS INFO IS HANDLED IN THE GRID ARCHITECTURE.
-    #BUT THIS IS ONE WAY OF PASSING IT THROUGH...
-    panel <- .train_position_ternary(panel,get("scale_T"),get("scale_L"),get("scale_R"))
-    panel$Wlabel = .Wlabel(panel,plot$labels)
-    for(i in 1:3){
-      x = scales.tern[i]
-      panel[[paste0(x,"_scales")]]$name <- do.call(paste0(".",x,"label"),list(panel  = panel,labels = plot$labels))
-    } 
+    ##Update the scale limits from the coordinate system
+    for(X in c(scales.tern,scales.cart))
+      plot$coordinates$limits[[X]] <- is.numericor(.select.lim(plot$scales$get_scales(X)$limits, plot$coordinates$limits[[X]]),c(0,1))
+    
+    #Store coordinates for use by other methods, AFTER the limits have been updated (ie the previous command)
+    set_last_coord(plot$coordinates) 
+    
+    #Normally this info is handled in the by grid, however, this is one way of passing it through
+    panel <- .train_position_ternary(panel,plot$scales$get_scales("T"),plot$scales$get_scales("L"),plot$scales$get_scales("R"))
+    
+    #get snapshot of panel so updates to panel dont interfere through the next loop.
+    panel.bup <- panel 
+    
+    #Assign the names Ternary scales and Wlabel (arrow label suffix) to the panel
+    for(X in scales.tern){
+      #Resolve the 'effective' T, L and R index, for case of non default coord_tern T, L and R assignments
+      XResolved <- scales.tern[which(scales.aes == plot$coordinates[[X]])] 
+      #Make update scale names, on effective axes.
+      #Executes .Tlabel, .Llabel and .Rlabel
+      panel[[paste0(X,"_scales")]]$name <- do.call(paste0(".",X,"label"),list(panel = panel.bup,labels = plot$labels))
+    }
+    
+    #Make update to axes arrow suffix label
+    panel$Wlabel = .Wlabel(panel,labels = plot$labels)
+    
+    #DONE
   }else set_last_coord(NULL)
   
-  layers <- plot$layers
+  layers     <- plot$layers
   layer_data <- lapply(layers, function(y) y$data)
   
   scales <- plot$scales
@@ -99,7 +105,7 @@ ggplot_build <- function(plot) {
   scale_y <- function() scales$get_scales("y")
   
   panel <- ggint$train_position(panel, data, scale_x(), scale_y())
-  data  <- ggint$map_position(panel, data, scale_x(), scale_y())
+  data  <- ggint$map_position(panel,   data, scale_x(), scale_y())
   
   # Apply and map statistics
   data <- calculate_stats(panel, data, layers)
